@@ -266,17 +266,20 @@ void DiscoverPage::checkAdapters()
         return;
     }
 
+    QAction *fixAdapters = new QAction(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), i18nc("Action to fix a problem", "Fix it"), m_warningWidget);
+    connect(fixAdapters, &QAction::triggered, this, &DiscoverPage::fixAdaptersError);
+
     m_warningWidget = new KMessageWidget(this);
     m_warningWidget->setMessageType(KMessageWidget::Warning);
     m_warningWidget->setCloseButtonVisible(false);
     if (m_manager->isBluetoothBlocked()) {
         m_warningWidget->setText(i18n("Bluetooth is disabled."));
+        fixAdapters->setText(i18nc("Action to enable Bluetooth adapter", "Enable"));
     } else {
         m_warningWidget->setText(i18n("Your Bluetooth adapter is not pairable."));
+        fixAdapters->setText(i18nc("Action to make Bluetooth adapter pairable", "Make Pairable"));
     }
 
-    QAction *fixAdapters = new QAction(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")), i18nc("Action to fix a problem", "Fix it"), m_warningWidget);
-    connect(fixAdapters, &QAction::triggered, this, &DiscoverPage::fixAdaptersError);
     m_warningWidget->addAction(fixAdapters);
     verticalLayout->insertWidget(0, m_warningWidget);
 }
