@@ -34,9 +34,9 @@ class FailPage : public QWizardPage, Ui::Fail
     Q_OBJECT
 
 public:
-    explicit FailPage(BlueWizard *parent = 0);
+    explicit FailPage(BlueWizard *parent = nullptr);
 
-    void initializePage() Q_DECL_OVERRIDE;
+    void initializePage() override;
 
 private:
     BlueWizard *m_wizard;
